@@ -20,7 +20,8 @@ project_root_dir = command_args.project_root_dir
 
 def restart(args=None):
     os.system(f'cd {project_root_dir};git pull')
-    kill_str = f'''ps -aux|grep {script_name} |grep -v grep|grep -v auto_restart_when_git_changed |grep -v  auto_restart_tool|awk '{{print $2}}' |xargs kill -9;'''
+    # kill_str = f'''ps -aux|grep {script_name} |grep -v grep|grep -v auto_restart_when_git_changed |grep -v  auto_restart_tool|awk '{{print $2}}' |xargs kill -9;'''
+    kill_str = f'''ps auxww | grep '{start_shell_str}' | awk '{{print $2}}' | xargs kill;'''
     os.system(kill_str)
     start_shell_str_full = f''' cd {project_root_dir};export PYTHONPATH=./:$PYTHONPATH;{start_shell_str}'''
     threading.Thread(target=os.system, args=(start_shell_str_full,)).start()
